==> openscada-0.2.6.tar.gz: openscada-0.2.6/src/moduls/ui/web_dbg/web_dbg.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Roman Savochenko                                *
 *   rom_as@fromru.com                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef WEB_DBG_H
#define WEB_DBG_H

#include <tuis.h>

namespace WebDbg
{
    class TWEB: public TUI
    {
	public:
	    TWEB( string name );
	    ~TWEB();
	
	    void mod_CheckCommandLine( );
	public:
    
	private:
	    void HttpGet( const string &url, string &page, const string &sender, vector<string> &vars );
	    void HttpPost( const string &url, string &page, const string &sender, vector<string> &vars, const string &contein );
	    
	    void pr_opt_descr( FILE * stream );	
	    string mod_info( const string &name );
	    void   mod_info( vector<string> &list );
	private:
	    static SExpFunc ExpFuncLc[];	

	    static char *w_head;	
	    static char *w_head_;	
	    static char *w_body;	
	    static char *w_body_;	
    };    
}
#endif //WEB_DBG_H

==> openscada-0.3.1.tar.gz: openscada-0.3.1/src/moduls/ui/web_dbg/web_dbg.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Roman Savochenko                                *
 *   rom_as@fromru.com                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef WEB_DBG_H
#define WEB_DBG_H

#include <tuis.h>

namespace WebDbg
{
    class TWEB: public TUI
    {
	public:
	    TWEB( string name );
	    ~TWEB();
	
	    void modCheckCommandLine( );
	public:
    
	private:
	    void HttpGet( const string &url, string &page, const string &sender, vector<string> &vars );
	    void HttpPost( const string &url, string &page, const string &sender, vector<string> &vars, const string &contein );
	    
	    string optDescr( );
	    string modInfo( const string &name );
	    void   modInfo( vector<string> &list );
	private:
	    static TModule::SExpFunc ExpFuncLc[];	

	    static char *w_head;	
	    static char *w_head_;	
	    static char *w_body;	
	    static char *w_body_;	
    };    
}
#endif //WEB_DBG_H
